from ocp_resources.resource import Resource


class OAuth(Resource):
    """
    OAuth object.
    """

    api_group = Resource.ApiGroup.CONFIG_OPENSHIFT_IO
